@@ -56,8 +56,8 @@ class MapResults(object):
         if not self._results_as_dict:
             size = self.df.memory_usage().sum()
             if self._verbose > 1 or self._verbose > 0 and size > 1000000:
-                print('converting Pandas DataFrame to listdict, size was {} bytes'.format(size))
-            self._results_as_dict = self.pd.to_dict(orient='records')
+                print('converting Pandas DataFrame to listdict, pandas size was {} bytes'.format(size))
+            self._results_as_dict = self._results.to_dict(orient='records')
         return self._results_as_dict
 
     @property
@@ -74,6 +74,7 @@ class MapResults(object):
         return self._stats
 
 
+'''
 class PDFWrapper(object):
     def __init__(self, df, verbose=0):
         self.df = df
@@ -95,6 +96,7 @@ class PDFWrapper(object):
                 print('converting Pandas DataFrame to listdict, size was {} bytes'.format(size))
             self._as_dict = self.pd.to_dict(orient='records')
         return self._as_dict
+'''
 
 
 def report_progress(system_kwargs, final=False):
@@ -258,7 +260,7 @@ def handle_return_common(out_func, ret, system_stats, system_kwargs, user_kwargs
             # XXX inefficient to append rows one at a time?
             system_kwargs['results'] = system_kwargs['results'].append(new_row, ignore_index=True)
 
-            progress.finished += len(ret)
+            progress.finished += 1
             if verbose > 1:
                 print('finished: pset {} result {}'.format(repr(user_ret['pset']), repr(user_ret['result'])), file=sys.stderr)
         if out_func:
